@@ -82,7 +82,7 @@ update_label (TeplTabLabel *tab_label)
 	/* A GtkNotebook tab label doesn't support well an ellipsizing GtkLabel.
 	 * So, ellipsize ourself.
 	 */
-	truncated_short_title = _tepl_utils_str_middle_truncate (short_title, MAX_LABEL_CHARS_LENGTH);
+	truncated_short_title = tepl_utils_str_middle_truncate (short_title, MAX_LABEL_CHARS_LENGTH);
 
 	gtk_label_set_text (tab_label->priv->label, truncated_short_title);
 
@@ -266,7 +266,7 @@ tepl_tab_label_get_tooltip_markup_default (TeplTabLabel *tab_label)
 	}
 
 	parse_name = g_file_get_parse_name (location);
-	parse_name_with_tilde = _tepl_utils_replace_home_dir_with_tilde (parse_name);
+	parse_name_with_tilde = tepl_utils_replace_home_dir_with_tilde (parse_name);
 
 	tooltip_markup = g_markup_printf_escaped ("<b>%s</b> %s",
 						  /* Translators: location of a file. */
